<?php
/**
 * Custom Functions.
 *
 * @package Alok
 */

if( !function_exists( 'alok_fonts_url' ) ) :

    //Google Fonts URL
    function alok_fonts_url(){

        $font_families = array(
            'Playfair+Display:wght@400;500;600;700',
            'Source+Sans+3:wght@300;400;500;600',
        );

        $fonts_url = add_query_arg( array(
            'family' => implode( '&family=', $font_families ),
            'display' => 'swap',
        ), 'https://fonts.googleapis.com/css2' );

        return esc_url_raw($fonts_url);

    }

endif;

if( !function_exists('alok_read_more_render') ):

    function alok_read_more_render(){ ?>
         <div class="entry-meta">
             <div class="entry-meta-link">
                 <a href="<?php the_permalink(); ?>">
                     <?php esc_html_e('Read More','alok'); ?>
                 </a>
             </div>
         </div>

    <?php
    }

endif;

if( !function_exists( 'alok_social_menu_icon' ) ) :

    function alok_social_menu_icon( $item_output, $item, $depth, $args ) {

        // Add Icon
        if ( 'alok-social-menu' === $args->theme_location ) {

            $svg = Alok_SVG_Icons::get_theme_svg_name( $item->url );

            if ( empty( $svg ) ) {
                $svg = alok_the_theme_svg( 'link',$return = true );
            }

            $item_output = str_replace( $args->link_after, '</span>' . $svg, $item_output );
        }

        return $item_output;
    }
    
endif;

add_filter( 'walker_nav_menu_start_el', 'alok_social_menu_icon', 10, 4 );

if( !function_exists( 'alok_add_sub_toggles_to_main_menu' ) ) :

    function alok_add_sub_toggles_to_main_menu( $args, $item, $depth ) {

        // Add sub menu toggles to the Expanded Menu with toggles.
        if( isset( $args->show_toggles ) && $args->show_toggles ){

            // Wrap the menu item link contents in a div, used for positioning.
            $args->before = '<div class="submenu-wrapper">';
            $args->after  = '';

            // Add a toggle to items with children.
            if( in_array( 'menu-item-has-children', $item->classes, true ) ){

                $toggle_target_string = '.menu-item.menu-item-' . $item->ID . ' > .sub-menu';
                // Add the sub menu toggle.
                $args->after .= '<button class="toggle submenu-toggle" data-toggle-target="' . $toggle_target_string . '" data-toggle-type="slidetoggle" data-toggle-duration="250" aria-expanded="false"><span class="btn__content" tabindex="-1"><span class="screen-reader-text">' . __( 'Show sub menu', 'alok' ) . '</span>' . alok_the_theme_svg( 'chevron-down',$return = true ) . '</span></button>';

            }

            // Close the wrapper.
            $args->after .= '</div><!-- .submenu-wrapper -->';

            // Add sub menu icons to the primary menu without toggles.
        }elseif( 'alok-primary-menu' === $args->theme_location ){

            if( in_array( 'menu-item-has-children', $item->classes, true ) ){

                $args->after = '<span class="icon">'.alok_the_theme_svg('chevron-down',true).'</span>';

            }else{

                $args->after = '';

            }
        }

        return $args;

    }

endif;

add_filter( 'nav_menu_item_args', 'alok_add_sub_toggles_to_main_menu', 10, 3 );


/**
 * Alok SVG Icon helper functions
 *
 * @package Alok
 * @since 1.0.0
 */
if ( ! function_exists( 'alok_the_theme_svg' ) ):
    /**
     * Output and Get Theme SVG.
     * Output and get the SVG markup for an icon in the Alok_SVG_Icons class.
     *
     * @param string $svg_name The name of the icon.
     * @param string $group The group the icon belongs to.
     * @param string $color Color code.
     */
    function alok_the_theme_svg( $svg_name, $return = false ) {

        if( $return ){

            return alok_get_theme_svg( $svg_name ); //phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped -- Escaped in alok_get_theme_svg();.

        }else{

            echo alok_get_theme_svg( $svg_name ); //phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped -- Escaped in alok_get_theme_svg();.
            
        }
    }

endif;

if ( ! function_exists( 'alok_get_theme_svg' ) ):

    /**
     * Get information about the SVG icon.
     *
     * @param string $svg_name The name of the icon.
     * @param string $group The group the icon belongs to.
     * @param string $color Color code.
     */
    function alok_get_theme_svg( $svg_name ) {

        // Make sure that only our allowed tags and attributes are included.
        $svg = wp_kses(
            Alok_SVG_Icons::get_svg( $svg_name ),
            array(
                'svg'     => array(
                    'class'       => true,
                    'xmlns'       => true,
                    'width'       => true,
                    'height'      => true,
                    'viewbox'     => true,
                    'aria-hidden' => true,
                    'role'        => true,
                    'focusable'   => true,
                    ' preserveAspectRatio' => true,
                ),
                'path'    => array(
                    'fill'      => true,
                    'fill-rule' => true,
                    'd'         => true,
                    'transform' => true,
                ),
                'polygon' => array(
                    'fill'      => true,
                    'fill-rule' => true,
                    'points'    => true,
                    'transform' => true,
                    'focusable' => true,
                ),
            )
        );
        if ( ! $svg ) {
            return false;
        }
        return $svg;

    }

endif;


                                
if( !function_exists( 'alok_vertical_header_section' ) ) :

    function alok_vertical_header_section(){
        $alok_default = alok_get_default_theme_options();

            $header_banner_title = get_theme_mod( 'header_banner_title',$alok_default['header_banner_title'] );
            $header_banner_description = get_theme_mod( 'header_banner_description',$alok_default['header_banner_description'] );
            $header_banner_signature_image = get_theme_mod( 'header_banner_signature_image');
            ?>
            <article>
               <div class="entry-wrapper">
                   <div class="post-content">
                       <header class="entry-header">
                           <h3 class="entry-title entry-title-big">
                                <?php echo esc_html($header_banner_title);?>
                           </h3>
                       </header>
                       
                       <div class="entry-excerpt">
                           <?php echo esc_html($header_banner_description); ?>
                       </div>
                       <?php if (!empty($header_banner_signature_image)) { ?>
                        <img src="<?php echo esc_url($header_banner_signature_image);?>">
                           
                       <?php } ?>
                   </div>
               </div>
            </article>
        <?php
    }

endif;

if( !function_exists( 'alok_post_category_list' ) ) :

    // Post Category List.
    function alok_post_category_list( $select_cat = true ){

        $post_cat_lists = get_categories(
            array(
                'hide_empty' => '0',
                'exclude' => '1',
            )
        );

        $post_cat_cat_array = array();
        if( $select_cat ){

            $post_cat_cat_array[''] = esc_html__( '-- Select Category --','alok' );

        }

        foreach ( $post_cat_lists as $post_cat_list ) {

            $post_cat_cat_array[$post_cat_list->slug] = $post_cat_list->name;

        }

        return $post_cat_cat_array;
    }

endif;

if( !function_exists('alok_sanitize_meta_pagination') ):

    /** Sanitize Enable Disable Checkbox **/
    function alok_sanitize_meta_pagination( $input ) {

        $valid_keys = array('global-layout','no-navigation','norma-navigation','ajax-next-post-load');
        if ( in_array( $input , $valid_keys ) ) {
            return $input;
        }
        return '';

    }

endif;

if( !function_exists('alok_disable_post_views') ):

    /** Disable Post Views **/
    function alok_disable_post_views() {

        add_filter('booster_extension_filter_views_ed', function ( ) {
            return false;
        });

    }

endif;

if( !function_exists('alok_disable_post_read_time') ):

    /** Disable Read Time **/
    function alok_disable_post_read_time() {

        add_filter('booster_extension_filter_readtime_ed', function ( ) {
            return false;
        });

    }

endif;

if( !function_exists('alok_disable_post_like_dislike') ):

    /** Disable Like Dislike **/
    function alok_disable_post_like_dislike() {

        add_filter('booster_extension_filter_like_ed', function ( ) {
            return false;
        });

    }

endif;

if( !function_exists('alok_disable_post_author_box') ):

    /** Disable Author Box **/
    function alok_disable_post_author_box() {

        add_filter('booster_extension_filter_ab_ed', function ( ) {
            return false;
        });

    }

endif;


add_filter('booster_extension_filter_ss_ed', function ( ) {
    return false;
});

if( !function_exists('alok_disable_post_reaction') ):

    /** Disable Reaction **/
    function alok_disable_post_reaction() {

        add_filter('booster_extension_filter_reaction_ed', function ( ) {
            return false;
        });

    }

endif;

if( !function_exists('alok_single_post_navigation') ):

    function alok_single_post_navigation(){

        $alok_default = alok_get_default_theme_options();
        $twp_navigation_type = esc_attr( get_post_meta( get_the_ID(), 'twp_disable_ajax_load_next_post', true ) );
        $current_id = '';
        $article_wrap_class = '';
        global $post;
        $current_id = $post->ID;
        if( $twp_navigation_type == '' || $twp_navigation_type == 'global-layout' ){
            $twp_navigation_type = get_theme_mod('twp_navigation_type', $alok_default['twp_navigation_type']);
        }


        if( $twp_navigation_type != 'no-navigation' && 'post' === get_post_type() ){

            if( $twp_navigation_type == 'norma-navigation' ){ ?>

                <div class="theme-block navigation-wrapper">
                    <?php
                    // Previous/next post navigation.
                    the_post_navigation(array(
                        'prev_text' => '<span class="arrow" aria-hidden="true">' . alok_the_theme_svg('arrow-left',$return = true ) . '</span><span class="screen-reader-text">' . __('Previous post:', 'alok') . '</span><h4 class="entry-title entry-title-small">%title</h4>',
                        'next_text' => '<span class="arrow" aria-hidden="true">' . alok_the_theme_svg('arrow-right',$return = true ) . '</span><span class="screen-reader-text">' . __('Next post:', 'alok') . '</span><h4 class="entry-title entry-title-small">%title</h4>',
                    )); ?>
                </div>
                <?php

            }else{

                $next_post = get_next_post();
                if( isset( $next_post->ID ) ){

                    $next_post_id = $next_post->ID;
                    echo '<div loop-count="1" next-post="' . absint( $next_post_id ) . '" class="twp-single-infinity"></div>';

                }
            }

        }

    }

endif;

add_action( 'alok_navigation_action','alok_single_post_navigation',30 );



if ( ! function_exists( 'alok_header_toggle_search' ) ):

    /**
     * Header Search
     **/
    function alok_header_toggle_search() {

        $alok_default = alok_get_default_theme_options();
        $ed_header_search = get_theme_mod( 'ed_header_search', $alok_default['ed_header_search'] );        
        if( $ed_header_search ){ ?>

            <div class="header-searchbar">
                <div class="header-searchbar-inner">
                    <div class="wrapper">

                        <div class="header-searchbar-area">

                            <a href="javascript:void(0)" class="skip-link-search-start"></a>
                            
                            <?php get_search_form(); ?>

                        </div>

                        <button type="button" id="search-closer" class="exit-search">
                            <?php alok_the_theme_svg('cross'); ?>
                        </button>

                        <a href="javascript:void(0)" class="skip-link-search-end"></a>

                    </div>
                </div>
            </div>

        <?php
        }

    }

endif;

add_action( 'alok_before_footer_content_action','alok_header_toggle_search',10 );

if( !function_exists('alok_content_offcanvas') ):

    // Offcanvas Contents
    function alok_content_offcanvas(){ ?>

        <div id="offcanvas-menu">
            <div class="offcanvas-wraper">

                <div class="close-offcanvas-menu">
                    <div class="offcanvas-close">

                        <a href="javascript:void(0)" class="skip-link-menu-start"></a>

                        <button type="button" class="button-offcanvas-close">
                            <?php alok_the_theme_svg('close'); ?>
                        </button>

                    </div>
                </div>

                <div id="primary-nav-offcanvas" class="offcanvas-item offcanvas-main-navigation">
                    <nav class="primary-menu-wrapper" aria-label="<?php esc_attr_e('Horizontal', 'alok'); ?>" role="navigation">
                        <ul class="primary-menu">

                            <?php
                            if( has_nav_menu('alok-primary-menu') ){

                                wp_nav_menu(
                                    array(
                                        'container' => '',
                                        'items_wrap' => '%3$s',
                                        'theme_location' => 'alok-primary-menu',
                                        'show_toggles' => true,
                                    )
                                );

                            }else{
                                
                                wp_list_pages(
                                    array(
                                        'match_menu_classes' => true,
                                        'show_sub_menu_icons' => false,
                                        'title_li' => false,
                                        'show_toggles' => true,
                                        'walker' => new Alok_Walker_Page(),
                                    )
                                );
                            } ?>

                        </ul>
                    </nav><!-- .primary-menu-wrapper -->
                </div>

                <?php if( has_nav_menu('alok-social-menu') ){ ?>

                    <div id="social-nav-offcanvas" class="offcanvas-item offcanvas-social-navigation">

                        <?php
                        wp_nav_menu(array(
                            'theme_location' => 'alok-social-menu',
                            'link_before' => '<span class="screen-reader-text">',
                            'link_after' => '</span>',
                            'container' => 'div',
                            'container_class' => 'social-menu',
                            'depth' => 1,
                        )); ?>

                    </div>

                <?php } ?>

                <a href="javascript:void(0)" class="skip-link-menu-end"></a>

            </div>
        </div>

    <?php
    }

endif;

add_action( 'alok_before_footer_content_action','alok_content_offcanvas',30 );

if( !function_exists('alok_footer_content_widget') ):

    function alok_footer_content_widget(){

        $alok_default = alok_get_default_theme_options();
        if( is_active_sidebar('alok-footer-widget-0') || 
            is_active_sidebar('alok-footer-widget-1') || 
            is_active_sidebar('alok-footer-widget-2') ):

            $x = 1;
            $footer_sidebar = 0;
            do {
                if ($x == 3 && is_active_sidebar('alok-footer-widget-2')) {
                    $footer_sidebar++;
                }
                if ($x == 2 && is_active_sidebar('alok-footer-widget-1')) {
                    $footer_sidebar++;
                }
                if ($x == 1 && is_active_sidebar('alok-footer-widget-0')) {
                    $footer_sidebar++;
                }
                $x++;
            } while ($x <= 3);
            if ($footer_sidebar == 1) {
                $footer_sidebar_class = 12;
            } elseif ($footer_sidebar == 2) {
                $footer_sidebar_class = 6;
            } else {
                $footer_sidebar_class = 4;
            }
            $footer_column_layout = absint(get_theme_mod('footer_column_layout', $alok_default['footer_column_layout'])); ?>

            <div class="footer-widgetarea">
                <div class="wrapper-small">
                    <div class="wrapper-inner">

                        <?php if (is_active_sidebar('alok-footer-widget-0')): ?>
                            <div class="column <?php echo 'column-' . absint($footer_sidebar_class); ?> column-sm-12">
                                <?php dynamic_sidebar('alok-footer-widget-0'); ?>
                            </div>
                        <?php endif; ?>

                        <?php if (is_active_sidebar('alok-footer-widget-1')): ?>
                            <div class="column <?php echo 'column-' . absint($footer_sidebar_class); ?> column-sm-12">
                                <?php dynamic_sidebar('alok-footer-widget-1'); ?>
                            </div>
                        <?php endif; ?>

                        <?php if (is_active_sidebar('alok-footer-widget-2')): ?>
                            <div class="column <?php echo 'column-' . absint($footer_sidebar_class); ?> column-sm-12">
                                <?php dynamic_sidebar('alok-footer-widget-2'); ?>
                            </div>
                        <?php endif; ?>

                    </div>
                </div>
            </div>

        <?php
        endif;

    }

endif;

add_action( 'alok_footer_content_action','alok_footer_content_widget',10 );


if( !function_exists('alok_footer_content_info') ):

    /**
     * Footer Copyright Area
    **/
    function alok_footer_content_info(){

        $alok_default = alok_get_default_theme_options(); ?>
        <div class="footer-credits">
            <div class="wrapper-small">
                <div class="wrapper-inner">

                    <div class="column column-10 ">

                        <div class="footer-copyright">

                            <?php
                            $ed_footer_copyright = wp_kses_post(get_theme_mod('ed_footer_copyright', $alok_default['ed_footer_copyright']));
                            $footer_copyright_text = wp_kses_post(get_theme_mod('footer_copyright_text', $alok_default['footer_copyright_text']));

                            echo esc_html__('Copyright ', 'alok') . '&copy ' . absint(date('Y')) . ' <a href="' . esc_url(home_url('/')) . '" title="' . esc_attr(get_bloginfo('name', 'display')) . '" ><span>' . esc_html(get_bloginfo('name', 'display')) . '. </span></a> ' . esc_html($footer_copyright_text);

                            if ($ed_footer_copyright) {

                                echo '<br>';
                                echo esc_html__('Theme: ', 'alok') . 'Alok ' . esc_html__('By ', 'alok') . '<a href="' . esc_url('https://www.themeinwp.com/theme/alok') . '"  title="' . esc_attr__('Themeinwp', 'alok') . '" target="_blank" rel="author"><span>' . esc_html__('Themeinwp. ', 'alok') . '</span></a>';

                                echo esc_html__('Powered by ', 'alok') . '<a href="' . esc_url('https://wordpress.org') . '" title="' . esc_attr__('WordPress', 'alok') . '" target="_blank"><span>' . esc_html__('WordPress.', 'alok') . '</span></a>';

                            } ?>

                        </div>

                    </div>

                    <div class="column column-2 ">
                        <?php alok_footer_go_to_top(); ?>
                    </div>

                </div>
            </div>
        </div>
    <?php
    }

endif;

add_action( 'alok_footer_content_action','alok_footer_content_info',20 );


if( !function_exists('alok_footer_go_to_top') ):

    // Scroll to Top render content
    function alok_footer_go_to_top(){ ?>

        <a class="to-the-top theme-action-control" href="#site-header">
            <span class="action-control-trigger" tabindex="-1">
                <span class="to-the-top-long">
                    <?php printf(esc_html__('To the top %s', 'alok'), '<span class="arrow" aria-hidden="true">&uarr;</span>'); ?>
                </span>
                <span class="to-the-top-short">
                    <?php printf(esc_html__('Up %s', 'alok'), '<span class="arrow" aria-hidden="true">&uarr;</span>'); ?>
                </span>
            </span>
        </a>
    
    <?php
    }

endif;

if( ! function_exists( 'alok_iframe_escape' ) ):
    
    /** Escape Iframe **/
    function alok_iframe_escape( $input ){

        $all_tags = array(
            'iframe'=>array(
                'width'=>array(),
                'height'=>array(),
                'src'=>array(),
                'frameborder'=>array(),
                'allow'=>array(),
                'allowfullscreen'=>array(),
            ),
            'video'=>array(
                'width'=>array(),
                'height'=>array(),
                'src'=>array(),
                'style'=>array(),
                'controls'=>array(),
            )
        );

        return wp_kses($input,$all_tags);
        
    }

endif;

if( class_exists( 'Booster_Extension_Class' ) ){

    add_filter('booster_extemsion_content_after_filter','alok_after_content_pagination');

}

if( !function_exists('alok_after_content_pagination') ):

    function alok_after_content_pagination($after_content){

        $pagination_single = wp_link_pages( array(
                    'before' => '<div class="page-links">' . esc_html__( 'Pages:', 'alok' ),
                    'after'  => '</div>',
                    'echo' => false
                ) );

        $after_content =  $pagination_single.$after_content;

        return $after_content;

    }

endif;

if( !function_exists('alok_excerpt_content') ):

    function alok_excerpt_content(){ 

        $alok_default = alok_get_default_theme_options();
        $ed_post_excerpt = get_theme_mod( 'ed_post_excerpt',$alok_default['ed_post_excerpt'] );

        if( $ed_post_excerpt ){ ?>
                    
            <div class="entry-content entry-content-small">

                <?php
                if( has_excerpt() ){

                    the_excerpt();

                }else{

                    echo esc_html( wp_trim_words( get_the_content(), 25, '...' ) );

                } ?>

            </div>

        <?php }
    }

endif;


if ( ! function_exists( 'alok_svg_escape' ) ):

    /**
     * Get information about the SVG icon.
     *
     * @param string $svg_name The name of the icon.
     * @param string $group The group the icon belongs to.
     * @param string $color Color code.
     */
    function alok_svg_escape( $input ) {

        // Make sure that only our allowed tags and attributes are included.
        $svg = wp_kses(
            $input,
            array(
                'svg'     => array(
                    'class'       => true,
                    'xmlns'       => true,
                    'width'       => true,
                    'height'      => true,
                    'viewbox'     => true,
                    'aria-hidden' => true,
                    'role'        => true,
                    'focusable'   => true,
                ),
                'path'    => array(
                    'fill'      => true,
                    'fill-rule' => true,
                    'd'         => true,
                    'transform' => true,
                ),
                'polygon' => array(
                    'fill'      => true,
                    'fill-rule' => true,
                    'points'    => true,
                    'transform' => true,
                    'focusable' => true,
                ),
            )
        );

        if ( ! $svg ) {
            return false;
        }

        return $svg;

    }

endif;

