<?php
/**
 *
 * Pagination Functions
 *
 * @package True News
 */

if( !function_exists('alok_archive_pagination_x') ):

	// Archive Page Navigation
	function alok_archive_pagination_x(){

		// Global Query
	    if( is_front_page() ){

	    	$posts_per_page = absint( get_option('posts_per_page') );
	        $paged_c = ( get_query_var( 'page' ) ) ? absint( get_query_var( 'page' ) ) : 1;
	        $posts_args = array(
	            'posts_per_page'        => $posts_per_page,
	            'paged'                 => $paged_c,
	        );
	        $posts_qry = new WP_Query( $posts_args );
	        $max = $posts_qry->max_num_pages;

	    }else{
	        global $wp_query;
	        $max = $wp_query->max_num_pages;
	        $paged_c = ( get_query_var( 'paged' ) > 1 ) ? get_query_var( 'paged' ) : 1;
	    }

		$alok_default = alok_get_default_theme_options();
		$alok_pagination_layout = esc_html( get_theme_mod( 'alok_pagination_layout',$alok_default['alok_pagination_layout'] ) );
		$alok_pagination_load_more = esc_html__('Load More Posts','alok');
		$alok_pagination_no_more_posts = esc_html__('No More Posts','alok');

		if( $alok_pagination_layout == 'next-prev' ){

            the_posts_navigation([
            	'prev_text'=>alok_the_theme_svg( 'arrow-left',$return = true ).'<span class="nav-link-label">'. __('Older posts','alok').'</span>',
				'next_text'=> '<span class="nav-link-label">'. __('Newer posts','alok').'</span>'.alok_the_theme_svg( 'arrow-right',$return = true ),
            ]);

		}elseif( $alok_pagination_layout == 'load-more' || $alok_pagination_layout == 'auto-load' ){ ?>

			<div class="theme-ajax-loadpost hide-no-js">

				<div  style="display: none;" class="theme-loaded-content"></div>
				

				<?php if( $max > 1 ){ ?>

					<button class="theme-loading-button theme-loading-style" href="javascript:void(0)">
						<span style="display: none;" class="theme-loading-status"></span>
						<span class="loading-text"><?php echo esc_html( $alok_pagination_load_more ); ?></span>
					</button>

				<?php }else{ ?>

					<button class="theme-loading-button theme-loading-style theme-no-posts" href="javascript:void(0)">
						<span style="display: none;" class="theme-loading-status"></span>
						<span class="loading-text"><?php echo esc_html( $alok_pagination_no_more_posts ); ?></span>
					</button>

				<?php } ?>

			</div>

		<?php }else{

			the_posts_pagination();

		}
			
	}

endif;
add_action('alok_archive_pagination','alok_archive_pagination_x',20);


add_action('wp_ajax_alok_single_infinity', 'alok_single_infinity_callback');
add_action('wp_ajax_nopriv_alok_single_infinity', 'alok_single_infinity_callback');

// Recommendec Post Ajax Call Function.
function alok_single_infinity_callback() {

    if ( isset( $_POST['_wpnonce'] ) && wp_verify_nonce( wp_unslash( $_POST['_wpnonce'] ), 'alok_ajax_nonce' ) ) {

    	$postid = '';
    	if( isset( $_POST['postid'] ) ){
	        $postid = absint( wp_unslash( $_POST['postid'] ) );
	    }
        $alok_default = alok_get_default_theme_options();
        $post_single_next_posts = new WP_Query( array( 'post_type' => 'post','post_status' => 'publish','posts_per_page' => 1, 'post__in' => array( absint( $postid ) ) ) );

		alok_disable_post_views();
		alok_disable_post_read_time();
		

        if ( $post_single_next_posts->have_posts() ) :
            while ( $post_single_next_posts->have_posts() ) :
                $post_single_next_posts->the_post();

				$alok_ed_post_views = esc_html( get_post_meta( get_the_ID(), 'alok_ed_post_views', true ) );
				$alok_ed_post_read_time = esc_html( get_post_meta( get_the_ID(), 'alok_ed_post_read_time', true ) );
				$alok_ed_post_like_dislike = esc_html( get_post_meta( get_the_ID(), 'alok_ed_post_like_dislike', true ) );
				$alok_ed_post_author_box = esc_html( get_post_meta( get_the_ID(), 'alok_ed_post_author_box', true ) );
				$alok_ed_post_social_share = esc_html( get_post_meta( get_the_ID(), 'alok_ed_post_social_share', true ) );
				$alok_ed_post_reaction = esc_html( get_post_meta( get_the_ID(), 'alok_ed_post_reaction', true ) );

                ob_start(); ?>


                <article id="post-<?php the_ID(); ?>" <?php post_class(); ?>>

                	<div class="wrapper-inner">
                		<div class="column column-6 column-sm-12">
                			<div class="theme-block-left">
                				<?php if( has_post_thumbnail() ){ ?>
                					<div class="entry-featured-thumbnail">
                						<div class="entry-thumbnail thumbnail-image-overlay">
                							<?php
                							$featured_image = wp_get_attachment_image_src( get_post_thumbnail_id(),'alok-featured-image' );
                							$featured_image = isset( $featured_image[0] ) ? $featured_image[0] : '';?>
                							<img src="<?php echo esc_url( $featured_image ); ?>" title="<?php the_title_attribute(); ?>" alt="<?php the_title_attribute(); ?>">
                						</div>
                					</div>
                					<div class="page-title-block">

                							<div class="entry-meta theme-meta-categories">
                								<?php alok_entry_footer( $cats = true, $tags = false, $edits = false ); ?>
                							</div>
                							

                						<header class="entry-header">

                							<h1 class="entry-title entry-title-big">

                								<?php the_title(); ?>

                							</h1>

                						</header>


                							<div class="entry-meta">
                								<?php alok_posted_by(); ?>
                							</div>
                					</div>
                				<?php } else { ?>
                					<div class="no-image-post">

                						<div class="no-image-excerpt">
                							<svg xmlns="http://www.w3.org/2000/svg" aria-hidden="true" role="img" width="1em" height="1em" preserveAspectRatio="xMidYMid meet" viewBox="0 0 24 24"><path fill="currentColor" d="m10 7l-2 4h3v6H5v-6l2-4h3m8 0l-2 4h3v6h-6v-6l2-4h3Z"/></svg>

                							<?php the_excerpt(); ?>
                						</div>

                						<div class="page-title-block">

                								<div class="entry-meta theme-meta-categories">
                									<?php alok_entry_footer( $cats = true, $tags = false, $edits = false ); ?>
                								</div>
                								
                							<header class="entry-header">

                								<h1 class="entry-title entry-title-big">

                									<?php the_title(); ?>

                								</h1>

                							</header>


                								<div class="entry-meta">
                									<?php alok_posted_by(); ?>
                								</div>
                						</div>
                					</div>
                				<?php } ?>
                			</div>
                		</div>

                		<div class="column column-6 column-sm-12">
                			<div class="theme-block-right">
                				
                				<div class="post-content-wrap">

                					<div class="post-content">

                						<div class="entry-content">

                							<?php

                							the_content( sprintf(
                								/* translators: %s: Name of current post. */
                								wp_kses( __( 'Continue reading %s <span class="meta-nav">&rarr;</span>', 'alok' ), array( 'span' => array( 'class' => array() ) ) ),
                								the_title( '<span class="screen-reader-text">"', '"</span>', false )
                							) );

                							if( !class_exists( 'Booster_Extension_Class' ) ){

                								wp_link_pages( array(
                									'before' => '<div class="page-links">' . esc_html__( 'Pages:', 'alok' ),
                									'after'  => '</div>',
                								) );

                							} ?>

                						</div>

                						<?php
                						if ( is_singular() && 'post' === get_post_type() ) { ?>

                							<div class="entry-footer">
                								<div class="entry-meta">
                									<?php alok_entry_footer( $cats = false, $tags = true, $edits = true ); ?>
                								</div>
                							</div>

                						<?php } ?>

                					</div>

                				</div>

                				<?php /**
                				 *  Output comments wrapper if it's a post, or if comments are open,
                				 * or if there's a comment number – and check for password.
                				**/

                				if ( ( is_single() || is_page() ) && ( comments_open() || get_comments_number() ) && !post_password_required() ) { ?>

                				    <div class="comments-wrapper">
                				        <?php comments_template(); ?>
                				    </div><!-- .comments-wrapper -->

                				<?php
                				} ?>
                			</div>
                		</div>
                	</div>

                </article>

                <?php
                $next_post_id = '';
                $next_post = get_next_post();
                if( isset( $next_post->ID ) ){ 
                    $next_post_id = $next_post->ID;
                }
                $output['postid'][] = $next_post_id;
                $output['content'][] = ob_get_clean();

            endwhile;

            wp_send_json_success($output);
            wp_reset_postdata();
        endif;
    }
    wp_die();
}
